﻿#
# This file is part of python sample package for the BROADWAY2 package.
#
# MIT License

# Copyright (c) 2013-2019 FibreCode GmbH <info@fibrecode.com>

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

# Important note:
# Starting with broadway2 V2.3.0 there is a split to stay on pure SMI/SPI access
# at broadway2-API.
# Means, all files/classes regarding register/property encoding to all Transceivers
# like NXP TJA1100/TJA1101 are no more availble on the broadway2 python installer.
# More details can be found on UM_broadway2_xxxx.pdf


import sys, os
import platform
import time, datetime

from broadway2 import Broadway, PhyAccess
from broadway2 import get_phy_access


def main(args):
    
    # create adapter singleton
    base = Broadway()

    if len(args) == 1:
        for adapter in base.enumerate():
            print('Adapter: {0}/{1}'.format(adapter.DevName, adapter.SerialNumber))
    elif len(args) == 2:
        instance = int(args[1])
        selAdapter = base.get_adapter(instance)
        if selAdapter.PhyType == 'NXP TJA1100' or selAdapter.PhyType == 'NXP TJA1101':
            dev = base.open_control(selAdapter.Inst)
            selAdapter.connect(dev)

            phyAccess = get_phy_access(selAdapter)
            
            print('Enable:{0}'.format(phyAccess.readreg(17) & 0x02))
            #print('Master:{0}'.format(phy.phyMaster))
            #print('LinkUp:{0}'.format(phy.linkUp))
            #print('SQI:{0}'.format(phy.networkQuality))

    elif len(args) == 3:
        selAdapter = None
        instance = int(args[1])
        mode = args[2].lower()
        print('selected {0} {1}'.format(instance, mode))
        selAdapter = base.get_adapter(instance)
        
        if selAdapter != None:
            print('Adapter: {0}'.format(selAdapter.SerialNumber))
            if selAdapter.PhyType == 'NXP TJA1100' or selAdapter.PhyType == 'NXP TJA1101':
                dev = base.open_control(selAdapter.Inst)
                
                selAdapter.connect(dev)
                phyAccess = get_phy_access(selAdapter)

                if selAdapter.PhyType == 'NXP TJA1100' or selAdapter.PhyType == 'NXP TJA1101':
                    # configEnable = True
                    reg17 = phyAccess.read_reg(17)
                    reg17 |= 0x02
                    reg17 &= ~0x80
                    phyAccess.write_reg(17, reg17)

                    time.sleep(1.0)

                    reg18 = phyAccess.read_reg(18)

                    if mode == 'm':
                        reg18 |= 0x80
                    elif mode == 's':
                        reg18 &= ~0x80

                    phyAccess.write_reg(18, reg18)
                        
                    reg17 |= 0x80
                    phyAccess.write_reg(17, reg17)
                    time.sleep(0.1)
                    
                    phy.disconnect()
                base.close(dev)


if __name__ == "__main__":
    main(sys.argv)
