#
# This file is part of python sample package for the BROADWAY2 package.
#
# MIT License

# Copyright (c) 2013-2019 FibreCode GmbH <info@fibrecode.com>

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

import sys, os
import binascii
import platform
import time, datetime

from broadway2 import Broadway, broadway_api, RawReceiver, RawRxHeaderTypes, EthFrame, RawRxFrame


DefaultInst = 0 # Use first found USB-Adapter
DefaultPayload = 512 #1484


def main(args):

    inst = DefaultInst
    payload = DefaultPayload

    
    # create adapter singleton
    base = Broadway()

    aList = base.get_raw_adapters()


    if len(aList) > 1:
        cnt = 1
        for a in aList:
            print('[ {0:2} ]: {1} / {2}'.format(cnt, a[1], a[0]))
            cnt += 1
        try:
            sel = int(input('Enter Number to use:'))
        except:
            sel = 0
        
    else:
        sel = 0


    inst, friendlyName = aList[sel-1]

    adapter = base.get_adapter(inst)


    print('Open Adapter to send raw: {0}'.format(adapter.FriendlyName))    
    print('='*30)
    if adapter != None:
        devTx = base.open_raw_tx(adapter.Inst)
        print('Raw Sender opened: {0}'.format(adapter.FriendlyName))

        devRx = base.open_raw_rx(adapter.Inst, RawRxHeaderTypes.HeaderType2)
        print('Raw Rx/Tx Device opened: {0}'.format(aList[sel][1]))

        rawReceiver = RawReceiver(devRx)

        rawReceiver.enable()

        if devTx == None or devRx == None:
            sys.exit(-1)

        payloadData = ''
        for j in range(0, payload):
            payloadData += '{0:02X}'.format(j & 0xFF)

        print('Send one frame to trigger echo!')

        sendData = 'FFFFFFFFFFFFFC0011223344' + '{0:04X}'.format(len(payloadData)) + payloadData
        binData = binascii.a2b_hex(sendData)

        res = broadway_api.wait_for_tx(devTx, 1000)
        if not res:
            print('waitfor tx failed!')

        frameId = broadway_api.submit_raw_frame(devTx, binData)

        res = broadway_api.send_raw_frames(devTx)
            
        res = broadway_api.wait_for_raw_tx_completion(devTx, frameId, 1000)

        hwTimeStamp = broadway_api.get_raw_tx_timestamp(devTx, frameId)

        sendData = 'FFFFFFFFFFFFFC0011223344' + '{0:04X}'.format(24) + '{0:016X}'.format(hwTimeStamp[0]) + '{0:08X}'.format(hwTimeStamp[1])
        binData = binascii.a2b_hex(sendData)
        frameId = broadway_api.submit_raw_frame(devTx, binData)

        res = broadway_api.send_raw_frames(devTx)

        print('Sent out: {0}.{1}!'.format(hwTimeStamp[0], hwTimeStamp[1]))

        time.sleep(0.1)

        result = rawReceiver.read_block(1000, 500)
        # returns array of tuples (timestamp, seqCounter, Ethernet-Frame)
        print('Received Frames: {0}'.format(len(result)))
        print('-'*48)
        for res in result:
            ethRaw = RawRxFrame(1, res)
            print(' -> Seq.{0:8} Timestamp: {1} s {2} ms'.format(ethRaw.SequenceCnt, ethRaw.TimestampSec, ethRaw.TimestampNano/1e6))
            print(' -> Data: {0}'.format(ethRaw.EthFrame.Data))
            timeSec = ethRaw.EthFrame.Data[0:16]
            timeNano = ethRaw.EthFrame.Data[16:24]
            ts = int(timeSec, 16)
            tsNano = int(timeNano, 16)
            print(ts, tsNano/1e6)

        base.close(devTx)
            

if __name__ == "__main__":
    main(sys.argv)

