#
# This file is part of python sample package for the BROADWAY2 package.
#
# MIT License

# Copyright (c) 2013-2019 FibreCode GmbH <info@fibrecode.com>

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.


import sys, os
import binascii
import platform
import time, datetime
import threading, queue
import binascii

from broadway2 import Broadway, RawReceiver, RawRxHeaderTypes, EthFrame, RawRxFrame


def main(args):
    
    # create adapter singleton
    base = Broadway()

    
    print('='*25)

    aList = base.get_raw_adapters()

    if len(aList) < 1:
        print('no Raw-Adapter found')
        sys.exit(-1)


    if len(aList) > 1:
        cnt = 1
        for a in aList:
            print('[ {0:2} ]: {1} / {2}'.format(cnt, a[1], a[0]))
            cnt += 1
        try:
            sel = int(input('Enter Number to use:'))
        except:
            sel = 0
        
    else:
        sel = 0
 
         
    if sel >= 0:
        inst, friendlyName = aList[sel-1]    # get adapter selected by instance    

        devRx = base.open_raw_rx(inst, RawRxHeaderTypes.HeaderType2)
        print('Raw Rx Device opened: {0} / {1}'.format(friendlyName, inst))

        rawReceiver = RawReceiver(devRx)

        rawReceiver.enable()

        print('Receiver running... Ctrl-C to exit')

        try:
            while 1:
                # read_block with max. 500 frames and timeout after 500 ms
                result = rawReceiver.read_block(1000, 500)
                # returns array of tuples (timestamp, seqCounter, Ethernet-Frame)
                print('Received Frames: {0}'.format(len(result)))
                print('-'*48)
                for res in result:
                    ethRaw = RawRxFrame(1, res)
                    print(' -> {0:8} {1}.{2}'.format(ethRaw.SequenceCnt, ethRaw.TimestampSec, ethRaw.TimestampNano))
                    eth = ethRaw.EthFrame
                    print('  {0} {1} {2}...'.format(str(eth), int(len(eth.Data)/2), eth.Data[0:16]))
                    print()
                    
                    # Test-Decoder in plain python as easy demo (no dependencies to other python packets)
                    # We recommend to have a look at pypacker, scapi, .... to avoid double-coding
                    
                    
                # give some time to gather on low-level driver
                time.sleep(0.1)
        except KeyboardInterrupt:

            rawReceiver.disable()

            base.close(devRx)


if __name__ == "__main__":
    main(sys.argv)
