#
# This file is part of python sample package for the BROADWAY2 package.
#
# MIT License

# Copyright (c) 2013-2019 FibreCode GmbH <info@fibrecode.com>

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.


import sys
import time
import binascii
import struct

from broadway2 import Broadway, SmiAccess, PhyTJA1101, PhyTJA1100
from broadway2 import get_phy_access

def main(args):
    
    base = Broadway()

    aList = base.get_tool_adapters()

    print('Num Tool Adapters found: {0}'.format(len(aList)))
    print()

    if len(aList) != 1:
        print('Please connect one FC401')
        sys.exit(-1)

    # verify to have just one Tool-Adapter connected
    
    inst, friendlyName = aList[0]

    adapter = base.get_adapter(inst)

    dev = base.open_control(inst)
    adapter.connect(dev)

    phyAccess = get_phy_access(adapter)

    if adapter.PhyType == 'NXP TJA1100':
        phy = PhyTJA1100(phyAccess)
    else:
        phy = PhyTJA1101(phyAccess)

    print('SQI: {0}'.format(phy.networkQuality))

    phy.configEnable = True
    phy.phyLinkControl = False
    phy.phyMaster = False

    phy.loopBack = False
    phy.loopbackMode = 3
    time.sleep(0.1)
    phy.loopBack = True
    phy.phyLinkControl = True

    print('Loopback Mode: {0}'.format(phy.loopbackMode))
    time.sleep(0.1)
    print('Phy configured to remote loopback')
        
    base.close(dev)


if __name__ == "__main__":
    main(sys.argv)



