#
# This file is part of python sample package for the BROADWAY2 package.
#
# MIT License

# Copyright (c) 2013-2019 FibreCode GmbH <info@fibrecode.com>

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.


import sys
import time
import binascii
import struct

from broadway2 import Broadway, SpiAccess, SmiAccess
from broadway2 import get_phy_access, get_spi_access, get_switch_access


ToolAdapterName = 'SJA1110EVM'


def main(args):
    
    base = Broadway()
    print('Adapters found: {0}'.format(base.Count))


    for adapter in base.enumerate():
        print('ProductId: {0:08X} DeviceType: {1} FriendlyName: {2}'.format(adapter.UsbProductId, adapter.DeviceType, adapter.FriendlyName))

    sja1110Adapter = base.get_adapter_by_name(ToolAdapterName)
    # verify to have just one Tool-Adapter connected
    if sja1110Adapter != None:
        print('Use Tool-Adapter: {0} / {1}'.format(sja1110Adapter.SerialNumber, sja1110Adapter.FriendlyName))

        dev = base.open_control(sja1110Adapter.Inst)

        # connect adapter instance to this control device
        sja1110Adapter.connect(dev)

        # SJA1110 A1-Sample uses Protocol=0, SJA1110.B1 Samples requires Protocol=1
        spiAccess = get_spi_access(sja1110Adapter, 1) 

        spiAccess.set_speed(int(8e6))
        
        sjaAccessA = get_switch_access(spiAccess, 0)
        sjaAccessB = get_switch_access(spiAccess, 1)

        smiAccess = SmiAccess(dev) # create smi adapter to smi-functions
    
        switchCoreIdA = sjaAccessA.read_reg(0)
        switchCoreIdB = sjaAccessB.read_reg(0)


        print('Switch Core ID (CS0): {0:08X}'.format(switchCoreIdA))
        print('Switch Core ID (CS1): {0:08X}'.format(switchCoreIdB))

        if switchCoreIdA == 0xB700030F:
            acuAddr = 0x1C4400 + (0x10>>2)
            acuRegs = sjaAccessA.read_regs(acuAddr, 4)
            
            
            for j in range(0,4):
                print('ACU: {0:08X} = {1:08X}'.format(acuAddr+j, acuRegs[j]))

            if switchCoreIdA == 0xB700030E:
                print('ACU: {0:08X}'.format(sjaAccessA.read_reg(0x1C4410)))

        elif switchCoreIdA == 0xB700030F:   # SJA1110.B1
            acuAddr = 0x1C4400 + (0x10>>2)
            acuRegs = sjaAccessA.read_regs(acuAddr, 4)
            
            
            for j in range(0,4):
                print('ACU: {0:08X} = {1:08X}'.format(acuAddr+j, acuRegs[j]))

            if switchCoreIdA == 0xB700030F:
                print('ACU: {0:08X}'.format(sjaAccessA.read_reg(0x1C4410)))


        elif switchCoreIdA == 0xCC335BCD:
            print('ACU0: {0:08X}'.format(sjaAccessA.read_reg(0xFF000000)))
            print('ACU1: {0:08X}'.format(sjaAccessA.read_reg(0xFF000000)))

        else:
            print('Unknown Device! Please verify SPI-connection')

        phyList = smiAccess.detect2()
        for phyAddr in phyList:
            
            phyAccess = get_phy_access(sja1110Adapter, phyAddr)
            if phyAccess != None:
                if phyAccess.supportsClause45:
                    print('C45 PhyAddr: {0:2}  PhyID: {1:04X}.{2:04X}'.format(phyAddr, phyAccess.read_dev_reg(0x1E, 2), phyAccess.read_dev_reg(0x1E, 3)))
                if phyAccess.supportsClause22:
                    print('C22 PhyAddr: {0:2}  PhyID: {1:04X}.{2:04X}'.format(phyAddr, phyAccess.read_reg(2), phyAccess.read_reg(3)))

        base.close(dev)
    else:
        print('no Tool Adapter found!')



if __name__ == "__main__":
    main(sys.argv)



